#!/bin/bash

################################################################################
##                                                                             #
## learning process of linear RAAM.                                            #
## input parameters loaded from params.sh in current directory                 #
##                                                                             #
## by Michal Pokorny                                                           #
##                                                                             #
################################################################################



## load params for simulation
. ./params.sh

## some necesarry control before we remove things we actually do not want to remove :)
if [ "x$TEMP_DIR" = "x" ]; then
    echo
    echo "BEWARE THE JABBERWOCK, MY SON!"
    echo "temp_dir not set!!!"
    echo
    exit
fi
if [ "x$STORE_DIR" = "x" ]; then
    echo
    echo "BEWARE THE JABBERWOCK, MY SON!"
    echo "store_dir not set!!!"
    echo
    exit
fi

## run $NOEX experiments
for EX in $(seq 1 $NOEX); do

    ## load simulation id (for unique prefixes) and create new id
    RUN_ID=$(cat .run)
    echo $(( $RUN_ID + 1 )) > .run

    ## clean temporary directory and create output directory
    cd $TEMP_DIR
    rm -f *
    cd ..
    cd $STORE_DIR
    rm -rf $RUN_ID
    mkdir $RUN_ID
    cd ..
    
    ## generate initial conditions
    R=$(( $RANDOM * $RANDOM ))
    PREFIX="$SIMULATION.$RUN_ID"
    lraam_init -d $DATASET -t $TERMSET -r $R -p $PRECISION -w $WEIGHT_BOUNDS > $TEMP_DIR/$PREFIX.0

    ## learning
    ITER=0
    while [ $ITER -lt $ITER_COUNT ]; do
	echo -ne "$ITER\t"
	cat $TEMP_DIR/$PREFIX.$ITER | lraam_learning -e $ETA -i $ITER_STEP > tmp
	let ITER=ITER+ITER_STEP
	mv tmp $TEMP_DIR/$PREFIX.$ITER
    done
    
    ## tar.gz results from this run
    cd $TEMP_DIR
    tar -cf $PREFIX.tar $PREFIX.*
    gzip $PREFIX.tar
    cd ..
    mv $TEMP_DIR/$PREFIX.tar.gz $STORE_DIR/$RUN_ID/$PREFIX.tar.gz
    cd $TEMP_DIR
    rm -f *
    cd ..    
    
    ## create README file for this run
    cd $STORE_DIR/$RUN_ID
    echo -n "" > $LOG_FILE
    echo "$SIMULATION: run number $RUN_ID" >> $LOG_FILE
    echo >> $LOG_FILE
    echo "learning rate ETA = $ETA" >> $LOG_FILE
    echo "number of iterations = $ITER_COUNT" >> $LOG_FILE
    echo "output after each $ITER_STEP simulations" >> $LOG_FILE
    echo "weights initialized from < -$WEIGHT_BOUNDS ; $WEIGHT_BOUNDS >" >> $LOG_FILE
    
    ## back to the starting directory
    cd ..
    cd ..

done

